==> nextcloud-app-spreed-4.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/pt_PT.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Validar certificado SSL",
    "Delete server" : "Apagar servidor",
    "Add new server" : "Adicionar novo servidor",
    "Saved" : "Gravado",
    "Shared secret" : "Segredo partilhado",
    "TURN server protocols" : "Protocolos do servidor TURN",
    "UDP and TCP" : "UDP e TCP",
    "UDP only" : "Só UDP",
    "TCP only" : "Só TCP",
    "Screensharing is not supported by your browser." : "O seu browser não suporta partilha de ecrã",
    "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
    "Screensharing options" : "Opções de partilha de ecrã",
    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
    "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
    "Participants" : "Participantes",
    "Chat" : "Conversa",
    "Talk" : "Falar",
    "Waiting for {participantName} to join the call …" : "À espera que {nomeDoParticipante} se junte à chamada ..",
    "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
    "No Camera" : "Sem Câmera",
    "Enable screensharing" : "Activar partilha de ecrã",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
    "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
    "Password required" : "Necessário palavra-passe",
    "Password" : "Palavra-passe",
    "Cancel" : "Cancelar",
    "Submit" : "Submeter",
    "Leave call" : "Sair da chamada",
    "Join call" : "Juntar-se à chamada",
    "Share link" : "Partilhar ligação",
    "Change password" : "Alterar palavra-passe",
    "Set password" : "Definir palavra-passe",
    "Name" : "Nome",
    "Rename" : "Renomear",
    "Copy link" : "Copiar ligação",
    "Conversation with {name}" : "Conversa com {nome}",
    "Error occurred while setting password" : "Ocorreu um erro a definir a palavra-passe",
    "Link copied!" : "Ligação copiada!",
    "You" : "Você",
    "No messages yet, start the conversation!" : "Ainda não tem mensagens, comece a conversa!",
    "Send" : "Enviar",
    "Guest" : "Convidado",
    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "{relativeDate}, {absoluteDate}" : "{dataRelativa}, {dataAbsoluta}",
    "Error occurred while sending message" : "Ocorreu um erro a enviar a mensagem",
    "Edit" : "Editar",
    "moderator" : "moderador",
    "Demote from moderator" : "Relegar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Remover participante",
    "No other people in this call" : "Sem mais pessoas nesta chamada",
    "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
    "Share this link to invite others!" : "Envie este link para convidar outros!",
    "Close" : "Fechar",
    "Waiting for camera and microphone permissions" : "À espera de permissões de câmera e microfone",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor, permite ao seu browser aceder à sua câmera e microfone para que possa utilizar esta aplicação.",
    "Disable video" : "desactivar vídeo",
    "Show screen" : "Mostrar ecrã",
    "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
    "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
    "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
    "WebRTC is not supported in your browser :-/" : "WebRTC não é suportado pelo seu browser :-/",
    "{participantName}'s screen" : "Ecrã de {nomeDeParticipante}",
    "Guest's screen" : "Ecrã do convidado",
    "Your screen" : "O seu ecrã",
    "(Duration %s)" : "(Duração %s)",
    "You attended a call with {user1}" : "Esteve numa chamada com {utilizador1}",
    "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {utilizador1} e {utilizador2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Esteve numa chamada com {utilizador1}, {utilizador2} e {utilizador3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Esteve numa chamada com {utilizador1}, {utilizador2}, {utilizador3} e {utilizador4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Esteve numa chamada com {utilizador1}, {utilizador2}, {utilizador3}, {utilizador4} e {utilizador5}",
    "{actor} invited you to {call}" : "{actor} convidou-o para {chamada}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Foi convidado para uma sala de <strong>conversa</strong> ou recebeu uma <strong>chamada</strong>",
    "Talk to %s" : "Falar com %s",
    ", " : ",",
    "{user} wants to talk with you" : "{utilizador} quer falar consigo",
    "A group call has started in {call}" : "Uma chamada de grupo começou em {chamada}",
    "(group)" : "(grupo)",
    "New public call" : "Nova chamada pública",
    "Looking great today! :)" : "Hoje está com óptimo aspecto! :)",
    "Time to call your friends" : "Está na hora de ligar aos seus amigos",
    "This call has ended" : "Esta chamada terminou",
    "and you" : "e você",
    "Please adjust your configuration" : "Por favor ajuste a sua configuração",
    "%s invited you to a private call" : "%s convidou-o para uma chamada privada",
    "{user} invited you to a private call" : "{utilizador} convidou-o para uma chamada privada",
    "%s invited you to a group call: %s" : "%s convidou-o para uma chamada de grupo: %s",
    "{user} invited you to a group call: {call}" : "{utilizador} convidou-o para uma chamada de grupo: {chamada}",
    "%s invited you to a group call" : "%s convidou-o para uma chamada de grupo",
    "{user} invited you to a group call" : "{utilizador} convidou-o para uma chamada de grupo",
    "Fullscreen" : "Ecrã completo",
    "Mute audio" : "Silenciar áudio",
    "… %s" : "... %s",
    "%s …" : "%s ...",
    "… %s …" : "... %s ..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-4.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/pt_PT.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Validar certificado SSL",
    "Delete server" : "Apagar servidor",
    "Add new server" : "Adicionar novo servidor",
    "Saved" : "Gravado",
    "Shared secret" : "Segredo partilhado",
    "UDP and TCP" : "UDP e TCP",
    "UDP only" : "Só UDP",
    "TCP only" : "Só TCP",
    "TURN server protocols" : "Protocolos do servidor TURN",
    "Screensharing is not supported by your browser." : "O seu browser não suporta partilha de ecrã",
    "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
    "Screensharing options" : "Opções de partilha de ecrã",
    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
    "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
    "Participants" : "Participantes",
    "Chat" : "Conversa",
    "Talk" : "Falar",
    "Waiting for {participantName} to join the call …" : "À espera que {nomeDoParticipante} se junte à chamada ..",
    "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
    "No Camera" : "Sem Câmera",
    "Enable screensharing" : "Activar partilha de ecrã",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
    "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
    "Password required" : "Necessário palavra-passe",
    "Password" : "Palavra-passe",
    "Cancel" : "Cancelar",
    "Submit" : "Submeter",
    "Leave call" : "Sair da chamada",
    "Join call" : "Juntar-se à chamada",
    "Share link" : "Partilhar ligação",
    "Change password" : "Alterar palavra-passe",
    "Set password" : "Definir palavra-passe",
    "Name" : "Nome",
    "Rename" : "Renomear",
    "Copy link" : "Copiar ligação",
    "Conversation with {name}" : "Conversa com {name}",
    "Error occurred while setting password" : "Ocorreu um erro a definir a palavra-passe",
    "Link copied!" : "Ligação copiada!",
    "You" : "Você",
    "No messages yet, start the conversation!" : "Ainda não tem mensagens, comece a conversa!",
    "New message …" : "Nova mensagem...",
    "Send" : "Enviar",
    "Share" : "Partilhar",
    "Guest" : "Convidado",
    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Ocorreu um erro a enviar a mensagem",
    "Edit" : "Editar",
    "moderator" : "moderador",
    "Demote from moderator" : "Relegar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Remover participante",
    "No other people in this call" : "Sem mais pessoas nesta chamada",
    "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
    "Share this link to invite others!" : "Envie este link para convidar outros!",
    "Close" : "Fechar",
    "Waiting for camera and microphone permissions" : "À espera de permissões de câmera e microfone",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor, permite ao seu browser aceder à sua câmera e microfone para que possa utilizar esta aplicação.",
    "Disable video" : "desactivar vídeo",
    "Show screen" : "Mostrar ecrã",
    "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
    "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
    "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
    "WebRTC is not supported in your browser :-/" : "WebRTC não é suportado pelo seu browser :-/",
    "{participantName}'s screen" : "Ecrã de {nomeDeParticipante}",
    "Guest's screen" : "Ecrã do convidado",
    "Your screen" : "O seu ecrã",
    "(Duration %s)" : "(Duração %s)",
    "You attended a call with {user1}" : "Esteve numa chamada com {utilizador1}",
    "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {utilizador1} e {utilizador2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Esteve numa chamada com {utilizador1}, {utilizador2} e {utilizador3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Esteve numa chamada com {utilizador1}, {utilizador2}, {utilizador3} e {utilizador4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Esteve numa chamada com {utilizador1}, {utilizador2}, {utilizador3}, {utilizador4} e {utilizador5}",
    "{actor} invited you to {call}" : "{actor} convidou-o para {chamada}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Foi convidado para uma sala de <strong>conversa</strong> ou recebeu uma <strong>chamada</strong>",
    "Talk to %s" : "Falar com %s",
    ", " : ",",
    "{user} wants to talk with you" : "{utilizador} quer falar consigo",
    "A group call has started in {call}" : "Uma chamada de grupo começou em {chamada}",
    "(group)" : "(grupo)",
    "New public call" : "Nova chamada pública",
    "Looking great today! :)" : "Hoje está com óptimo aspecto! :)",
    "Time to call your friends" : "Está na hora de ligar aos seus amigos",
    "This call has ended" : "Esta chamada terminou",
    "and you" : "e você",
    "Please adjust your configuration" : "Por favor ajuste a sua configuração",
    "%s invited you to a private call" : "%s convidou-o para uma chamada privada",
    "{user} invited you to a private call" : "{utilizador} convidou-o para uma chamada privada",
    "%s invited you to a group call: %s" : "%s convidou-o para uma chamada de grupo: %s",
    "{user} invited you to a group call: {call}" : "{utilizador} convidou-o para uma chamada de grupo: {chamada}",
    "%s invited you to a group call" : "%s convidou-o para uma chamada de grupo",
    "{user} invited you to a group call" : "{utilizador} convidou-o para uma chamada de grupo",
    "Fullscreen" : "Ecrã completo",
    "Mute audio" : "Silenciar áudio",
    "… %s" : "... %s",
    "%s …" : "%s ...",
    "… %s …" : "... %s ..."
},
"nplurals=2; plural=(n != 1);");
